@@ -108,7 +108,7 @@ struct _CalendarWindowPrivate {
 #endif /* HAVE_LIBECAL */
 };
 
-G_DEFINE_TYPE (CalendarWindow, calendar_window, GTK_TYPE_WINDOW);
+G_DEFINE_TYPE (CalendarWindow, calendar_window, GTK_TYPE_WINDOW)
 
 enum {
 	PROP_0,
@@ -388,6 +388,8 @@ is_appointment (GtkTreeModel *model,
 		return (g_ascii_strcasecmp (uri, "file")   == 0 ||
 			g_ascii_strcasecmp (uri, "webcal") == 0 ||
 			g_ascii_strcasecmp (uri, "caldav") == 0 ||
+			g_ascii_strcasecmp (uri, "exchange")  == 0 ||
+			g_ascii_strcasecmp (uri, "groupwise") == 0 ||
 			g_ascii_strcasecmp (uri, "google") == 0);
 	return FALSE;
 }
@@ -520,14 +522,18 @@ set_renderer_pixbuf_color_by_column (GtkCellRenderer *renderer,
 {
         char      *color_string;
         GdkPixbuf *pixbuf = NULL;
-        guint32    color;
+        GdkColor   color;
 
         gtk_tree_model_get (model, iter, column_number, &color_string, -1);
 
-        if (color_string) {
-                sscanf (color_string, "%06x", &color);
+        if (color_string && gdk_color_parse (color_string, &color)) {
                 pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, 16, 16);
-                gdk_pixbuf_fill (pixbuf, color << 8);
+                /* GdkColor has 16 bits per color, gdk_pixbuf only uses 8 bits
+                 * per color. So just drop the least significant parts */
+                gdk_pixbuf_fill (pixbuf,
+				 (color.red   & 0xff00) << 16 |
+				 (color.green & 0xff00) << 8  | 
+				 (color.blue  & 0xff00));
 
                 g_object_set (renderer, "visible", pixbuf != NULL, "pixbuf", pixbuf, NULL);
 
@@ -587,9 +593,9 @@ set_renderer_pixbuf_pixmap_for_bday (GtkCellRenderer *renderer,
 	 * pas-id-41112AF900000003-birthday
 	 * ...
 	 */
-	if (g_strrstr (type, "birthday") != 0)
+	if (g_strrstr (type, "birthday") != NULL)
 		path = CLOCK_EDS_ICONDIR G_DIR_SEPARATOR_S "category_birthday_16.png";
-	else if (g_strrstr (type, "anniversary") != 0)
+	else if (g_strrstr (type, "anniversary") != NULL)
 		path = CLOCK_EDS_ICONDIR G_DIR_SEPARATOR_S "category_gifts_16.png";
 	else
 		path = CLOCK_EDS_ICONDIR G_DIR_SEPARATOR_S "category_miscellaneous_16.png";
